@@ -184,8 +184,8 @@ class MODEL_SERVING:
     MODEL_SERVER_PYTHON = "PYTHON"
     MODEL_SERVERS = [MODEL_SERVER_TENSORFLOW_SERVING, MODEL_SERVER_PYTHON]
     SERVING_TOOL_DEFAULT = "DEFAULT"
-    SERVING_TOOL_KFSERVING = "KFSERVING"
-    SERVING_TOOLS = [SERVING_TOOL_DEFAULT, SERVING_TOOL_KFSERVING]
+    SERVING_TOOL_KSERVE = "KSERVE"
+    SERVING_TOOLS = [SERVING_TOOL_DEFAULT, SERVING_TOOL_KSERVE]
     INFERENCE_LOGGING_MODEL_INPUTS = "MODEL_INPUTS"
     INFERENCE_LOGGING_PREDICTIONS = "PREDICTIONS"
     INFERENCE_LOGGING_ALL = "ALL"
