@@ -473,12 +473,16 @@ def _attach_experiment_xattr(ml_id, json_data, op_type):
 
     response = util.send_request('PUT', resource_url, data=json_data, headers=headers)
 
-    response_object = response.json()
+    try:
+        response_object = response.json()
+    except ValueError:
+        response_object = {}
+
     if response.status_code >= 400:
         error_code, error_msg, user_msg = util._parse_rest_error(response_object)
         raise RestAPIError("Could not create experiment (url: {}), server response: \n "
-                           "HTTP code: {}, HTTP reason: {}, error code: {}, error msg: {}, user msg: {}".format(
-            resource_url, response.status_code, response.reason, error_code, error_msg, user_msg))
+                           "HTTP code: {}, HTTP reason: {}, body: {}, error code: {}, error msg: {}, user msg: {}".format(
+            resource_url, response.status_code, response.reason, response.content, error_code, error_msg, user_msg))
     else:
         return response_object
 
@@ -764,9 +768,9 @@ def _set_ml_id(app_id, run_id):
 def _get_metric(return_dict, metric_key):
     if return_dict and metric_key:
         assert metric_key in return_dict.keys(), 'Supplied metric_key {} is not in returned dict {}'.format(metric_key, return_dict)
-        return str(return_dict[metric_key])
+        return str(return_dict[metric_key]) if return_dict[metric_key] != None else None
     elif return_dict is not None and len(return_dict.keys()) == 2 and 'metric' in return_dict.keys():
-        return str(return_dict['metric'])
+        return str(return_dict['metric']) if return_dict['metric'] != None else None
     else:
         return None
 
